@@ -72,18 +72,20 @@ Arguments:
   arguments        Optional arguments for command.
 
 </source>
-        <translation>Употреба:% 1 опция [команда [аргументи ...]]
+        <translation>Употреба: %1 опция [команда [аргументи ...]]
 
 Графичен интерфейс за% 2 /% 3
 
 Аргументи:
    опция:
-     -h | --help Отпечатване на тази помощ.
-     -v | --version Информация за версията за печат.
-     -s | --su Използвайте% 3 (1) като бекенд.
-     -d | --sudo Използвайте% 2 (8) като бекенд.
-   команда Команда за изпълнение.
-   аргументи Незадължителни аргументи за команда.</translation>
+     -h | --help         Показване на тази помощ.
+     -v | --version   Информация за версията за печат.
+     -s | --su             Използване на %3(1) като бекенд.
+     -d | --sudo       Използване на %2(8) като бекенд.
+   команда           Команда за изпълнение.
+   аргументи    Незадължителни аргументи за команда.
+
+</translation>
     </message>
     <message>
         <location filename="../sudo.cpp" line="92"/>
